@@ -28,7 +28,7 @@ love.plot(w.out1,
           var.order = "unadjusted",
           abs = TRUE,
           line = TRUE, 
-          threshold = .1)
+          thresholds = c(m = .1))
 
 ## -----------------------------------------------------------------------------
 new.names <- c(age = "Age (Years)",
@@ -48,7 +48,7 @@ love.plot(w.out1,
           var.order = "unadjusted",
           abs = TRUE,
           line = TRUE, 
-          threshold = .1,
+          thresholds = c(m = .1),
           var.names = new.names,
           colors = c("red", "blue"),
           shapes = c("triangle filled", "circle filled"))
@@ -61,7 +61,7 @@ love.plot(w.out1,
           var.order = "unadjusted",
           abs = TRUE,
           line = TRUE, 
-          threshold = .1,
+          thresholds = c(m = .1),
           var.names = new.names,
           colors = c("red", "blue"),
           shapes = c("triangle filled", "circle filled"),
@@ -82,7 +82,7 @@ love.plot(treat ~ age + educ + married + nodegree + race + re74 + re75,
           var.order = "unadjusted",
           abs = TRUE,
           line = TRUE, 
-          threshold = .1,
+          thresholds = c(m = .1),
           var.names = new.names,
           colors = c("red", "blue", "darkgreen"),
           shapes = c("triangle filled", "circle filled", "square filled"),
@@ -101,7 +101,7 @@ love.plot(treat ~ age + educ + married + nodegree + race + re74 + re75,
           var.order = "unadjusted",
           abs = TRUE,
           line = TRUE, 
-          threshold = .1,
+          thresholds = c(m = .1),
           var.names = new.names,
           colors = c("red", "blue", "darkgreen"),
           shapes = c("triangle filled", "circle filled", "square filled"),
@@ -120,15 +120,14 @@ love.plot(treat ~ age + educ + married + nodegree + race + re74 + re75,
           var.order = "unadjusted",
           abs = TRUE,
           line = FALSE, 
-          threshold = c(mean.diffs = .1,
-                        ks = .05),
+          thresholds = c(m = .1, ks = .05),
           var.names = new.names,
           colors = c("red", "blue", "darkgreen"),
           shapes = c("triangle filled", "circle filled", "square filled"),
           sample.names = c("Unweighted", "PS Weighted", "CBPS Weighted"),
-          limits = list(mean.diffs = c(0, .82),
+          limits = list(m = c(0, .82),
                         ks = c(0, .45)),
-          wrap = 20, grid = FALSE,
+          wrap = 20,
           position = "top") 
 
 ## -----------------------------------------------------------------------------
@@ -136,7 +135,7 @@ love.plot(w.out1, abs = FALSE,
           stats = c("mean.diffs", "variance.ratios"),
           drop.distance = TRUE,
           var.names = new.names,
-          threshold = c(v = 2),
+          thresholds = c(v = 2),
           limits = list(m = c(-.9, .9),
                         v = c(.3, 6)),
           shapes = c("circle filled", "circle"),
